import java.awt.*;
import java.awt.event.*;
import java.io.IOException;

import javax.swing.*;

/** Class for an application that displays SOHO images from the internet. */

public class JSolarViewerApp_2 {
    private JFrame m_jxFrameMainApp = new JFrame();
    private int m_intFrameWidth, m_intFrameHeight;
    private JMenu m_jxMenuFile = new JMenu("File");
    private JMenu m_jxMenuFilter = new JMenu("Filter");
    private JMenu m_jxMenuInfo = new JMenu("Info");
    private JMenuBar m_jxMenuBar = new JMenuBar();
    private JMenuItem m_jxMenuItemExit = new JMenuItem("Exit");
    private String[] m_jStringFilter 
            = { "EIT 171", 
                "EIT 195", 
                "EIT 284", 
                "EIT 304", 
                "SDO/HMI Continuum",
                "SDO/HMI Magnetogram", 
                "LASCO C2", 
                "LASCO C3" };
    private JRadioButtonMenuItem[] m_jxRadioButtonMenuItems = new JRadioButtonMenuItem[8];
    private JMenuItem m_jxMenuItemAbout = new JMenuItem("About...");
    private ButtonGroup m_jxButtonGroupFilter = new ButtonGroup();
    private JPanel m_jxPanelSouth = new JPanel();
    private JLabel m_jxLabelStatus = new JLabel("Ready");
    private JLabel m_jxLabelCoordinates = new JLabel();
    private JEditorPane m_jxEditorPane = new JEditorPane();
    private JScrollPane m_jxScrollPane = new JScrollPane(m_jxEditorPane);
    final private String m_jStringURLPrefix = "https://soho.nascom.nasa.gov/data/realtime/";
    final private String m_jStringURLSuffix = "/1024/latest.html";
    private String m_jStringURLFilter = new String();

    /** Class that handles Exit menu item events. */

    class ExitInfoListener implements ActionListener {
        public ExitInfoListener() {}
        public void actionPerformed(ActionEvent l_jActionEvent) {
            if (l_jActionEvent.getActionCommand().equals(m_jxMenuItemExit.getText())) {
                System.exit(0);
            }
            else if (l_jActionEvent.getActionCommand().equals(m_jxMenuItemAbout.getText())) {
                JOptionPane.showMessageDialog(m_jxFrameMainApp, "Displays NASA's SOHO images from the internet.",
                 m_jxFrameMainApp.getTitle(), JOptionPane.PLAIN_MESSAGE);
            }
        }
    }

    /** Class that handles menu items. */

    class FilterListener implements ItemListener {
        public FilterListener() {}
        public void itemStateChanged(ItemEvent l_jItemEvent) {
            JRadioButtonMenuItem l_jxRadioButtonMenuItem = (JRadioButtonMenuItem) l_jItemEvent.getItem();
            String l_jStringFilterType = l_jxRadioButtonMenuItem.getText();

            if (l_jStringFilterType.equals(m_jStringFilter[0])) { m_jStringURLFilter = "eit_171"; }
            if (l_jStringFilterType.equals(m_jStringFilter[1])) { m_jStringURLFilter = "eit_195"; }
            if (l_jStringFilterType.equals(m_jStringFilter[2])) { m_jStringURLFilter = "eit_284"; }
            if (l_jStringFilterType.equals(m_jStringFilter[3])) { m_jStringURLFilter = "eit_304"; }
            if (l_jStringFilterType.equals(m_jStringFilter[4])) { m_jStringURLFilter = "hmi_igr"; }
            if (l_jStringFilterType.equals(m_jStringFilter[5])) { m_jStringURLFilter = "hmi_mag"; }
            if (l_jStringFilterType.equals(m_jStringFilter[6])) { m_jStringURLFilter = "c2"; }
            if (l_jStringFilterType.equals(m_jStringFilter[7])) { m_jStringURLFilter = "c3"; }

            String l_jStringURLFull = m_jStringURLPrefix + m_jStringURLFilter + m_jStringURLSuffix;
            m_jxLabelStatus.setText(l_jStringURLFull);
            m_jxFrameMainApp.setTitle("Solar Viewer - " + l_jStringFilterType);

            try {
                m_jxEditorPane.setPage(l_jStringURLFull);
            } catch (IOException e) {
                // TODO Auto-generated catch block
                e.printStackTrace();
            }        
        }
    }

    /** Class for getting mouuse pointer coordinates. */

    class CoordinateListener implements MouseMotionListener {
        private static final String STRING = "  (";
        private String l_jStringURL_Coordinates;
        public CoordinateListener() {}
        public void mouseDragged(MouseEvent l_jMouseEvent) {}
        public void mouseMoved(MouseEvent l_jMouseEvent) {
            l_jStringURL_Coordinates = STRING + l_jMouseEvent.getX() + "," + l_jMouseEvent.getY() +")";
            m_jxLabelCoordinates.setText(l_jStringURL_Coordinates);  
        }
    }

    /** Initialize the application. */

    private void init() {
        this.m_jxMenuFile.add(this.m_jxMenuItemExit);

        for (int l_intArrayElement = 0; l_intArrayElement < 8; l_intArrayElement++) {
            this.m_jxRadioButtonMenuItems[l_intArrayElement]
              = new JRadioButtonMenuItem(this.m_jStringFilter[l_intArrayElement]);

            this.m_jxMenuFilter.add(this.m_jxRadioButtonMenuItems[l_intArrayElement]);
            this.m_jxButtonGroupFilter.add(this.m_jxRadioButtonMenuItems[l_intArrayElement]);
            this.m_jxRadioButtonMenuItems[l_intArrayElement].addItemListener(new FilterListener());
        }

        this.m_jxMenuInfo.add(this.m_jxMenuItemAbout);
        this.m_jxMenuBar.add(this.m_jxMenuFile);
        this.m_jxMenuBar.add(this.m_jxMenuFilter);
        this.m_jxMenuBar.add(this.m_jxMenuInfo);
        this.m_jxPanelSouth.setLayout(new FlowLayout(FlowLayout.LEFT));
        this.m_jxPanelSouth.add(this.m_jxLabelStatus);
        this.m_jxPanelSouth.add(this.m_jxLabelCoordinates);
        this.m_jxFrameMainApp.getContentPane().add(this.m_jxPanelSouth, BorderLayout.SOUTH);
        this.m_jxFrameMainApp.setJMenuBar(this.m_jxMenuBar);
        this.m_jxEditorPane.setEditable(false);
        this.m_jxEditorPane.addMouseMotionListener(new CoordinateListener());
        this.m_jxFrameMainApp.getContentPane().add(this.m_jxScrollPane, BorderLayout.CENTER);

        this.m_jxMenuItemAbout.addActionListener(new ExitInfoListener());
        this.m_jxMenuItemAbout.setMnemonic(KeyEvent.VK_A);
        this.m_jxMenuItemExit.addActionListener(new ExitInfoListener());
        this.m_jxMenuItemExit.setMnemonic(KeyEvent.VK_X);

        this.m_intFrameHeight 
        = (int) this.m_jxFrameMainApp.getGraphicsConfiguration().getBounds().getHeight() - 100;

        this.m_intFrameWidth
        = (int) this.m_jxFrameMainApp.getGraphicsConfiguration().getBounds().getWidth() / 2;

        this.m_jxFrameMainApp.setSize(this.m_intFrameWidth, this.m_intFrameHeight);
        this.m_jxFrameMainApp.setTitle("Solar Viewer");
        extracted();
        this.m_jxFrameMainApp.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        this.m_jxFrameMainApp.setVisible(true);
    }

    private void extracted() {
        this.m_jxFrameMainApp.setLocationRelativeTo(null);
    }

    /** No-argument constructor. */

    public JSolarViewerApp_2() {
        init();
    }

    public static void main(String args[]) {
        JSolarViewerApp_2 l_jxSolarViewerApp_2 = new JSolarViewerApp_2();
        System.out.println("Running " + l_jxSolarViewerApp_2.toString());
    }
}